########
commands
########

.. toctree::
   :maxdepth: 1

   build_contributors
   check_adobefonts
   check_googlefonts
   check_opentype
   check_profile
   check_ufo_sources
   check_universal
   generate_glyphdata
